@@ -7,12 +7,15 @@ use Scalar::Util qw/blessed/;
 use Params::Validate qw/:all/;
 use B qw/svref_2object/;
 use Exporter 'import';
+use Acme::AsciiEmoji;
 
+our @EMO = @Acme::AsciiEmoji::EXPORT_OK;
 our @EXPORT = qw/render_me moon_test moon_test_one sunrise/;
-
+our @EXPORT_OK = (qw/render_me moon_test moon_test_one sunrise/, @EMO);
 our %EXPORT_TAGS = (
-    all     => [qw/render_me moon_test moon_test_one sunrise/],
-    element => [qw/render_me sunrise/]
+    all     => [qw/render_me moon_test moon_test_one sunrise/, @EMO],
+    element => [qw/render_me sunrise/],
+    emo     => [@EMO],
 );
 
 use feature qw/switch/;
@@ -24,11 +27,11 @@ Moonshine::Test - Test!
 
 =head1 VERSION
 
-Version 0.10
+Version 0.11
 
 =cut
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 =head1 SYNOPSIS
 
@@ -668,7 +671,7 @@ sub sunrise {
     my $done_testing = done_testing(shift);
     diag explain $done_testing;
     diag sprintf( '
-                                   %s
+                                  %s
             ^^                   @@@@@@@@@
        ^^       ^^            @@@@@@@@@@@@@@@
                             @@@@@@@@@@@@@@@@@@              ^^
@@ -679,7 +682,7 @@ sub sunrise {
    -  --     -         -      ------  -- ---       -- - --  -- -
  -  -       - -      -           -- ------  -      --  -             --
        -             -        -      -      --   -             -',
-        shift // ' \o/ ' );
+        shift // '  \o/  ' );
     return $done_testing;
 }
 
